@@ -1,17 +1,17 @@
 from dataclasses import dataclass, field
-from typing import Optional, Union
+from typing import Union
 
 from brain_brew.build_tasks.crowd_anki.headers_from_crowdanki import headers_default_values
-from brain_brew.representation.build_config.representation_base import RepresentationBase
-from brain_brew.representation.yaml.deck_part_holder import DeckPartHolder
-from brain_brew.representation.yaml.headers_repr import Headers
+from brain_brew.configuration.part_holder import PartHolder
+from brain_brew.configuration.representation_base import RepresentationBase
+from brain_brew.representation.yaml.headers import Headers
 
 
 @dataclass
 class HeadersToCrowdAnki:
     @dataclass
     class Representation(RepresentationBase):
-        deck_part: str
+        part_id: str
 
     @classmethod
     def from_repr(cls, data: Union[Representation, dict, str]):
@@ -21,18 +21,15 @@ class HeadersToCrowdAnki:
         elif isinstance(data, dict):
             rep = cls.Representation.from_dict(data)
         else:
-            rep = cls.Representation(deck_part=data)  # Support single string being passed in
+            rep = cls.Representation(part_id=data)  # Support single string being passed in
 
         return cls(
-            headers_to_read=rep.deck_part
+            headers=PartHolder.from_file_manager(rep.part_id).part
         )
 
-    headers_to_read: str
-    headers: Headers = field(init=False)
+    headers: Headers
 
     def execute(self) -> dict:
-        self.headers = DeckPartHolder.from_deck_part_pool(self.headers_to_read).deck_part
-
         headers = self.headers_to_crowd_anki(self.headers.data_without_name)
 
         return headers
